<?php

namespace SlotDb\Cli\Command\Group;

use SlotDb\Client\SlotDbClient;
use Symfony\Component\Console\Attribute\AsCommand;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Helper\Table;
use Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;

#[AsCommand(name:"group:show", description:"Show slots in a group")]
class GroupShowCommand extends Command
{
    public function __construct(
        private readonly SlotDbClient $client
    )
    {
        parent::__construct();
    }

    protected function configure()
    {
        $this->addArgument("group", InputArgument::REQUIRED, "Group to display");
    }

    protected function execute(InputInterface $input, OutputInterface $output): int
    {
        $groupId = $input->getArgument("group");
        
        $slots = $this->client->queryGroupSlots($groupId);

        $keys = [];
        foreach ($slots as $slot) {
            $keys = array_merge($keys, array_keys($slot));
        }
        $keys = array_unique($keys);

        $table = new Table($output);
        $table->setHeaders($keys);
        $table->setStyle('box');
        foreach ($slots as $slot) {
            $row = [];
            foreach ($keys as $key) {
                $row[] = isset($slot[$key]) ? json_encode($slot[$key]) : null;
            }
            $table->addRow($row);
        }

        $table->render();

        return self::SUCCESS;
    }
}
